@@ -55,9 +55,7 @@ foreach my $jobtype (keys %jobs_all, keys %jobs) {
           if exists $jobs{$jobtype} and not param('device');
 
         add_job($jobtype, param('device'), param('extra'));
-
-        header(Location => uri_for('/admin/jobqueue')->path);
-        return status(302);
+        redirect uri_for('/admin/jobqueue')->path;
     };
 }
 
