@@ -1,7 +1,6 @@
 package App::Netdisco::Web::Plugin::Report::ApChannelDist;
 
 use Dancer ':syntax';
-use Dancer::Plugin::Ajax;
 use Dancer::Plugin::DBIC;
 use Dancer::Plugin::Auth::Extensible;
 
@@ -11,10 +10,11 @@ register_report(
     {   category => 'Wireless',
         tag      => 'apchanneldist',
         label    => 'Access Point Channel Distribution',
+        provides_csv => 1,
     }
 );
 
-ajax '/ajax/content/report/apchanneldist' => require_login sub {
+get '/ajax/content/report/apchanneldist' => require_login sub {
     my $set = schema('netdisco')->resultset('DevicePortWireless')->search(
         { channel => { '!=', '0' } },
         {   select   => [ 'channel', { count => 'channel' } ],
@@ -23,12 +23,17 @@ ajax '/ajax/content/report/apchanneldist' => require_login sub {
             order_by => { -desc => [qw/count/] },
         },
     );
-
     return unless $set->count;
 
-    content_type('text/html');
-    template 'ajax/report/apchanneldist.tt', { results => $set, },
-        { layout => undef };
+    if (request->is_ajax) {
+        template 'ajax/report/apchanneldist.tt', { results => $set, },
+            { layout => undef };
+    }
+    else {
+        header( 'Content-Type' => 'text/comma-separated-values' );
+        template 'ajax/report/apchanneldist_csv.tt', { results => $set, },
+            { layout => undef };
+    }
 };
 
 true;
